@@ -14,7 +14,7 @@ use Getopt::Long 2.33;
 use Scalar::Util 1.26 qw{ blessed looks_like_number };
 use Text::ParseWords ();
 
-our $VERSION = '0.049_05';
+our $VERSION = '0.049_06';
 
 our @CARP_NOT = qw{
     Astro::App::Satpass2
@@ -59,6 +59,7 @@ our @EXPORT_OK = qw{
     __legal_options
     __parse_class_and_args
     ARRAY_REF CODE_REF HASH_REF REGEXP_REF SCALAR_REF
+    HAVE_DATETIME
     @CARP_NOT
 };
 
@@ -72,6 +73,17 @@ use constant HASH_REF	=> ref {};
 use constant REGEXP_REF	=> ref qr{};
 use constant SCALAR_REF	=> ref \1;
 
+{
+    local $@ = undef;
+
+    use constant HAVE_DATETIME => eval {
+	require DateTime;
+	require DateTime::TimeZone;
+	1;
+    } || 0;
+
+}
+
 # Documented in POD
 
 {
@@ -879,6 +891,12 @@ This constant is simply C<ref qr{}>.
 
 This constant is simply C<ref \1>.
 
+=head2 HAVE_DATETIME
+
+This Boolean constant is true if L<DateTime|DateTime> and
+L<DateTime::TimeZone|DateTime::TimeZone> can be loaded, and false if
+not.
+
 =head1 GLOBALS
 
 This module exports the following globals:
